@@ -84,7 +84,10 @@ class SIXExchangeCalendar(MarketCalendar):
 
     """
     aliases = ['SIX']
-
+    regular_market_times = {
+        "market_open": ((None, time(9)),),
+        "market_close": ((None, time(17,30)),),
+    }
     @property
     def name(self):
         return "SIX"
@@ -93,14 +96,6 @@ class SIXExchangeCalendar(MarketCalendar):
     def tz(self):
         return timezone('Europe/Zurich')
 
-    @property
-    def open_time_default(self):
-        return time(9, 0, tzinfo=self.tz)
-
-    @property
-    def close_time_default(self):
-        return time(17, 30, tzinfo=self.tz)
-
     @property
     def regular_holidays(self):
         return AbstractHolidayCalendar(rules=[
