@@ -173,5 +173,8 @@ UniqueCloses.append(pd.Timestamp("1973-11-14", tz='UTC'))     # Wedding Day of P
 UniqueCloses.append(pd.Timestamp("1981-07-29", tz='UTC'))     # Wedding Day of Prince Charles and Diana Spencer
 UniqueCloses.append(pd.Timestamp("2011-04-29", tz='UTC'))     # Wedding Day of Prince William and Catherine Middleton
 
+# Coronation of King Charles III
+UniqueCloses.append(pd.Timestamp("2023-05-08", tz='UTC'))
+
 # Miscellaneous
 UniqueCloses.append(pd.Timestamp("1999-12-31", tz='UTC'))     # Eve of 3rd Millenium A.D.
